pub fn check_scope_ownership(
registries: &[(&str, &[&DiagnosticInfo])],
) -> Vec<String>Expand description
Check that two crates do not claim the same NAMESPACE.SCOPE prefix.
pub fn check_scope_ownership(
registries: &[(&str, &[&DiagnosticInfo])],
) -> Vec<String>Check that two crates do not claim the same NAMESPACE.SCOPE prefix.